==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ToolActionCheckboxInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionCheckboxInfoDescription } from "./ToolActionCheckboxInfoDescription";
/**
 * @hidden
 */
var ToolActionCheckboxInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionCheckboxInfoDescriptionMetadata, _super);
    function ToolActionCheckboxInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionCheckboxInfoDescriptionMetadata.b = function (a) {
        if (ToolActionCheckboxInfoDescriptionMetadata.a == null) {
            ToolActionCheckboxInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionCheckboxInfoDescriptionMetadata.c(ToolActionCheckboxInfoDescriptionMetadata.a);
        }
        if (a.k(ToolActionCheckboxInfoDescriptionMetadata.a)) {
            return;
        }
        a.ab(ToolActionCheckboxInfoDescriptionMetadata.a);
    };
    ToolActionCheckboxInfoDescriptionMetadata.c = function (a) {
        ToolActionInfoDescriptionMetadata.c(a);
        a.item("IsChecked", "Boolean");
    };
    ToolActionCheckboxInfoDescriptionMetadata.d = function (a) {
        ToolActionCheckboxInfoDescriptionMetadata.b(a);
        a.ad("ToolActionCheckboxInfo", function () { return new ToolActionCheckboxInfoDescription(); });
        a.ac("ToolActionCheckboxInfo", ToolActionCheckboxInfoDescriptionMetadata.a);
    };
    ToolActionCheckboxInfoDescriptionMetadata.$t = markType(ToolActionCheckboxInfoDescriptionMetadata, 'ToolActionCheckboxInfoDescriptionMetadata');
    ToolActionCheckboxInfoDescriptionMetadata.a = null;
    return ToolActionCheckboxInfoDescriptionMetadata;
}(Base));
export { ToolActionCheckboxInfoDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/ToolActionCheckboxInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionCheckboxInfoDescription } from "./ToolActionCheckboxInfoDescription";
/**
 * @hidden
 */
var ToolActionCheckboxInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionCheckboxInfoDescriptionMetadata, _super);
    function ToolActionCheckboxInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionCheckboxInfoDescriptionMetadata.b = function (a) {
        if (ToolActionCheckboxInfoDescriptionMetadata.a == null) {
            ToolActionCheckboxInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionCheckboxInfoDescriptionMetadata.c(ToolActionCheckboxInfoDescriptionMetadata.a);
        }
        if (a.k(ToolActionCheckboxInfoDescriptionMetadata.a)) {
            return;
        }
        a.ac(ToolActionCheckboxInfoDescriptionMetadata.a);
    };
    ToolActionCheckboxInfoDescriptionMetadata.c = function (a) {
        ToolActionInfoDescriptionMetadata.c(a);
        a.item("IsChecked", "Boolean");
    };
    ToolActionCheckboxInfoDescriptionMetadata.d = function (a) {
        ToolActionCheckboxInfoDescriptionMetadata.b(a);
        a.ae("ToolActionCheckboxInfo", function () { return new ToolActionCheckboxInfoDescription(); });
        a.ad("ToolActionCheckboxInfo", ToolActionCheckboxInfoDescriptionMetadata.a);
    };
    ToolActionCheckboxInfoDescriptionMetadata.$t = markType(ToolActionCheckboxInfoDescriptionMetadata, 'ToolActionCheckboxInfoDescriptionMetadata');
    ToolActionCheckboxInfoDescriptionMetadata.a = null;
    return ToolActionCheckboxInfoDescriptionMetadata;
}(Base));
export { ToolActionCheckboxInfoDescriptionMetadata };
